@@ -59,20 +59,21 @@
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-build-basic-autotools-plugin.xml"
 #define MAX_BUILD_PANES 3
-#define PREF_INDICATORS_AUTOMATIC "indicators.automatic"
-#define PREF_INSTALL_ROOT "build.install.root"
-#define PREF_INSTALL_ROOT_COMMAND "build.install.root.command"
-#define PREF_PARALLEL_MAKE "build.parallel.make"
-#define PREF_PARALLEL_MAKE_JOB "build.parallel.make.job"
-#define PREF_TRANSLATE_MESSAGE "build.translate.message"
-#define PREF_CONTINUE_ON_ERROR "build.continue.error"
+#define PREF_SCHEMA "org.gnome.anjuta.build"
+#define PREF_INDICATORS_AUTOMATIC "build-indicators-automatic"
+#define PREF_INSTALL_ROOT "build-install-root"
+#define PREF_INSTALL_ROOT_COMMAND "build-install-root-command"
+#define PREF_PARALLEL_MAKE "build-parallel-make"
+#define PREF_PARALLEL_MAKE_JOB "build-parallel-make-job"
+#define PREF_TRANSLATE_MESSAGE "build-translate-message"
+#define PREF_CONTINUE_ON_ERROR "build-continue-error"
 
-#define BUILD_PREFS_DIALOG "preferences_dialog_build"
-#define BUILD_PREFS_ROOT "preferences_build_container"
-#define INSTALL_ROOT_CHECK "preferences_toggle:bool:0:0:build.install.root"
-#define INSTALL_ROOT_ENTRY "preferences_entry:text:sudo:0:build.install.root.command"
-#define PARALLEL_MAKE_CHECK "preferences_toggle:bool:0:0:build.parallel.make"
-#define PARALLEL_MAKE_SPIN "preferences_spin:int:1:0:build.parallel.make.job"
+#define BUILD_PREFS_DIALOG "preferences-dialog-build"
+#define BUILD_PREFS_ROOT "preferences-build-container"
+#define INSTALL_ROOT_CHECK "preferences_toggle:bool:0:0:build-install-root"
+#define INSTALL_ROOT_ENTRY "preferences_combo:text:sudo, su -c:0:build-install-root-command"
+#define PARALLEL_MAKE_CHECK "preferences_toggle:bool:0:0:build-parallel-make"
+#define PARALLEL_MAKE_SPIN "preferences_spin:int:1:0:build-parallel-make-job"
 
 #define DEFAULT_COMMAND_COMPILE "make"
 #define DEFAULT_COMMAND_BUILD "make"
@@ -212,11 +213,22 @@ directory_has_makefile_am (BasicAutotoolsPlugin *bb_plugin, const char *dirname
 	}
 	g_free (configure);
 
-	/* Check for Makefile.am */
+	/* Check for Makefile.am or GNUmakefile.am */
+	
+	makefile_am_exists = TRUE;
+	
 	makefile_am = g_build_filename (dirname, "Makefile.am", NULL);
-	makefile_am_exists = g_file_test (makefile_am, G_FILE_TEST_EXISTS);
-	g_free (makefile_am);
+	if (! g_file_test (makefile_am, G_FILE_TEST_EXISTS)) {
+		g_free (makefile_am);
 
+		makefile_am = g_build_filename (dirname, "GNUmakefile.am", NULL);
+		if (!g_file_test (makefile_am, G_FILE_TEST_EXISTS)) {
+			g_free (makefile_am);
+	
+			makefile_am_exists = FALSE;
+		}
+	}
+	
 	return makefile_am_exists;
 }
 
@@ -961,7 +973,7 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 			context->locations = g_slist_prepend (context->locations, loc);
 			
 			/* If current editor file is same as indicator file, set indicator */
-			if (anjuta_preferences_get_bool (anjuta_shell_get_preferences (context->plugin->shell, NULL), PREF_INDICATORS_AUTOMATIC))
+			if (g_settings_get_boolean (p->settings, PREF_INDICATORS_AUTOMATIC))
 			{
 				build_indicator_location_set (loc, p->current_editor,
 											  p->current_editor_filename);
@@ -1317,18 +1329,18 @@ build_set_command_in_context (BuildContext* context, BuildProgram *prog)
 static gboolean
 build_execute_command_in_context (BuildContext* context, GError **err)
 {
-	AnjutaPreferences* prefs = anjuta_shell_get_preferences (context->plugin->shell, NULL);
+	GSettings* settings = ANJUTA_PLUGIN_BASIC_AUTOTOOLS(context->plugin)->settings;
 	
 	/* Send options to make */
 	if (strcmp (build_program_get_basename (context->program), "make") == 0)
 	{
-		if (anjuta_preferences_get_bool (prefs , PREF_PARALLEL_MAKE))
+		if (g_settings_get_boolean (settings, PREF_PARALLEL_MAKE))
 		{
-			gchar *arg = g_strdup_printf ("-j%d", anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE_JOB));
+			gchar *arg = g_strdup_printf ("-j%d", g_settings_get_int (settings , PREF_PARALLEL_MAKE_JOB));
 			build_program_insert_arg (context->program, 1, arg);
 			g_free (arg);
 		}
-		if (anjuta_preferences_get_bool (prefs , PREF_CONTINUE_ON_ERROR))
+		if (g_settings_get_boolean (settings, PREF_CONTINUE_ON_ERROR))
 		{
 			build_program_insert_arg (context->program, 1, "-k");
 		}
@@ -1337,7 +1349,7 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	/* Set a current working directory which can contains symbolic links */
 	build_program_add_env (context->program, "PWD", context->program->work_dir);
 
-	if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
+	if (!g_settings_get_boolean (settings, PREF_TRANSLATE_MESSAGE))
 	{
 		build_program_add_env (context->program, "LANGUAGE", "C");
 	}
@@ -1641,15 +1653,11 @@ build_is_file_built (BasicAutotoolsPlugin *plugin, const gchar *filename,
 static gchar*
 get_root_install_command(BasicAutotoolsPlugin *bplugin)
 {
-	AnjutaPlugin* plugin = ANJUTA_PLUGIN(bplugin);
-	AnjutaPreferences* prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
-	if (anjuta_preferences_get_bool (prefs , PREF_INSTALL_ROOT))
+	GSettings* settings = bplugin->settings;
+	if (g_settings_get_boolean (settings, PREF_INSTALL_ROOT))
 	{
-		gchar* command = anjuta_preferences_get(prefs, PREF_INSTALL_ROOT_COMMAND);
-		if (command != NULL)
-			return command;
-		else
-			return g_strdup("");
+		gchar* command = g_settings_get_string (settings, PREF_INSTALL_ROOT_COMMAND);
+		return command;
 	}
 	else
 		return g_strdup("");
@@ -1668,7 +1676,7 @@ build_install_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname,
 	prog = build_program_new_with_command (build_dir,
 	                                       "%s %s",
 	                                       root,
-	                                       CHOOSE_COMMAND (plugin, INSTALL)),
+	                                       CHOOSE_COMMAND (plugin, INSTALL));
 	build_program_set_callback (prog, callback, user_data);	
 	
 	context = build_save_and_execute_command (plugin, prog, TRUE, err);
@@ -2658,7 +2666,7 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildCleanProject");
-	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
+	g_object_set (G_OBJECT (action), "sensitive", has_makefile, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
 								   "ActionBuildDistribution");
 	g_object_set (G_OBJECT (action), "sensitive", has_project, NULL);
@@ -2986,16 +2994,14 @@ value_added_project_build_uri (AnjutaPlugin *plugin, const gchar *name,
 static gint
 on_update_indicators_idle (gpointer data)
 {
-	AnjutaPlugin *plugin = ANJUTA_PLUGIN (data);
 	BasicAutotoolsPlugin *ba_plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (data);
 	IAnjutaEditor *editor = ba_plugin->current_editor;
 	
 	/* If indicators are not yet updated in the editor, do it */
 	if (ba_plugin->current_editor_filename &&
 		IANJUTA_IS_INDICABLE (editor) &&
-		anjuta_preferences_get_bool (anjuta_shell_get_preferences (plugin->shell,
-																  NULL),
-									PREF_INDICATORS_AUTOMATIC))
+		g_settings_get_boolean (ba_plugin->settings,
+		                        PREF_INDICATORS_AUTOMATIC))
 	{
 		GList *node;
 		node = ba_plugin->contexts_pool;
@@ -3243,6 +3249,10 @@ deactivate_plugin (AnjutaPlugin *plugin)
 static void
 dispose (GObject *obj)
 {
+	BasicAutotoolsPlugin *ba_plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (obj);
+
+	g_object_unref (ba_plugin->settings);
+	
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
@@ -3299,6 +3309,7 @@ basic_autotools_plugin_instance_init (GObject *obj)
 	ba_plugin->last_exec_uri = NULL;
 	ba_plugin->editors_created = g_hash_table_new (g_direct_hash,
 												   g_direct_equal);
+	ba_plugin->settings = g_settings_new (PREF_SCHEMA);
 }
 
 static void
@@ -3536,6 +3547,7 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 	GtkWidget *root_entry;
 	GtkWidget *make_entry;
 	GtkBuilder *bxml;
+	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (ipref);
 		
 	/* Create the preferences page */
 	bxml =  anjuta_util_builder_new (BUILDER_FILE, NULL);
@@ -3554,7 +3566,8 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 	g_signal_connect(G_OBJECT(make_check), "toggled", G_CALLBACK(on_root_check_toggled), make_entry);
 	on_root_check_toggled (make_check, make_entry);
 	
-	anjuta_preferences_add_from_builder (prefs, bxml, BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
+	anjuta_preferences_add_from_builder (prefs, bxml, plugin->settings, 
+	                                     BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
 	
 	g_object_unref (bxml);
 }
