@@ -22,6 +22,7 @@
 #include <plugins/project-wizard/autogen.h>
 
 #include <libanjuta/anjuta-marshal.h>
+#include <libanjuta/anjuta-utils.h>
 
 #include <glib/gstdio.h>
 
@@ -77,7 +78,7 @@ cg_generator_make_absolute (const gchar *path)
 	}
 	else
 	{
-		current_dir = g_get_current_dir ();
+		current_dir = anjuta_util_get_current_dir ();
 		abs_path = g_build_filename (current_dir, path, NULL);
 		g_free (current_dir);
 	}
