@@ -35,7 +35,7 @@
 
 #include "window.h"
 
-#define ICON_FILE "class_logo.xpm"
+#define ICON_FILE "anjuta-class-gen-plugin-48.png"
 
 static gpointer parent_class;
 
@@ -178,7 +178,7 @@ cg_plugin_add_to_project (AnjutaClassGenPlugin *plugin,
 	IAnjutaProjectManager *manager;
 	GList *filenames;
 	GList *added_files;
-	GList *node;
+	GFile *file;
 	gboolean result;
 
 	manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell,
@@ -187,36 +187,25 @@ cg_plugin_add_to_project (AnjutaClassGenPlugin *plugin,
 	if (manager == NULL) 
 		return FALSE;
 
-	filenames = NULL;
-	filenames = g_list_append (filenames, g_path_get_basename (header_file));
+	filenames = g_list_append (NULL, g_path_get_basename (header_file));
 	filenames = g_list_append (filenames, g_path_get_basename (source_file));
+	file = g_file_new_for_path (plugin->top_dir);
 	added_files = ianjuta_project_manager_add_sources (manager, filenames,
-	                                                   plugin->top_dir, NULL);
-	if (g_list_length (added_files) != 2)
-	{
-		for (node = added_files; node != NULL; node = g_list_next (node))
-			g_free (node->data);
-
-		result = FALSE;
-	}
-	else
-	{
-		GFile *file;
-
-		file = g_file_new_for_uri ((gchar *)added_files->data);
-		*new_header_file = g_file_get_path(file);
-		g_object_unref (file);
-		file = g_file_new_for_uri ((gchar *)g_list_next (added_files)->data);
-		*new_source_file = g_file_get_path(file);
-		g_object_unref (file);
-		
-		result = TRUE;
-	}
-
-	g_list_foreach (added_files, (GFunc)g_free, NULL);
-	g_list_free (added_files);
+	                                                   file, NULL);
+	g_object_unref (file);
+	g_list_foreach (filenames, (GFunc)g_free, NULL);
 	g_list_free (filenames);
 
+	result = g_list_length (added_files) == 2;
+	if (result)
+	{
+		*new_header_file = g_file_get_path((GFile *)added_files->data);
+		*new_source_file = g_file_get_path((GFile *)g_list_next (added_files)->data);
+	}
+
+	g_list_foreach (added_files, (GFunc)g_object_unref, NULL);
+	g_list_free (added_files);
+
 	return result;
 }
 
@@ -326,13 +315,8 @@ cg_plugin_generator_created_cb (CgGenerator *generator,
 		manager = anjuta_shell_get_interface (ANJUTA_PLUGIN (plugin)->shell, IAnjutaProjectManager, NULL);
 		if (manager)
 		{
-			gchar *huri = g_file_get_uri (header);
-			gchar *suri = g_file_get_uri (source);
-
-			g_signal_emit_by_name (G_OBJECT (manager), "element_added", huri);
-			g_signal_emit_by_name (G_OBJECT (manager), "element_added", suri);
-			g_free (huri);
-			g_free (suri);
+			g_signal_emit_by_name (G_OBJECT (manager), "element_added", header);
+			g_signal_emit_by_name (G_OBJECT (manager), "element_added", source);
 		}
 
 		g_object_unref (header);
@@ -454,6 +438,8 @@ cg_plugin_window_response_cb (G_GNUC_UNUSED GtkDialog *dialog,
 	}
 }
 
+#define PREF_SCHEMA "org.gnome.anjuta"
+
 static void
 iwizard_activate (IAnjutaWizard *wiz, G_GNUC_UNUSED GError **err)
 {
@@ -471,10 +457,9 @@ iwizard_activate (IAnjutaWizard *wiz, G_GNUC_UNUSED GError **err)
 
 	cg_plugin->window = cg_window_new ();
 
-	user_name = anjuta_preferences_get (cg_plugin->prefs,
-	                                    "anjuta.user.name");
-	user_email = anjuta_preferences_get (cg_plugin->prefs,
-	                                     "anjuta.user.email");
+	user_name = g_strdup(g_get_real_name ());
+	/* FIXME: */
+	user_email = anjuta_util_get_user_mail();
 	
 	if (user_name != NULL)
 		cg_window_set_author (cg_plugin->window, user_name);
