@@ -166,7 +166,8 @@ struct _DmaStart
 #define RUN_PROGRAM_ACTION_GROUP "ActionGroupRun"
 #define RUN_PROGRAM_PARAMETER_ACTION "ActionProgramParameters"
 
-#define PREFS_NOT_CHECK_DEBUG "debug_silent_non_debug_config"
+#define PREF_SCHEMA "org.gnome.anjuta.debug-manager"
+#define PREFS_NOT_CHECK_DEBUG "debug-silent-non-debug-config"
 
 static void attach_process_clear (AttachProcess * ap, gint ClearRequest);
 
@@ -797,11 +798,11 @@ attach_process_show (AttachProcess * ap, GtkWindow *parent)
 						  G_CALLBACK (on_selection_changed), ap);
 		g_signal_connect (G_OBJECT (ap->dialog), "delete_event",
 						  G_CALLBACK (on_delete_event), ap);
-		g_signal_connect (GTK_OBJECT (checkb_hide_paths), "toggled",
+		g_signal_connect (checkb_hide_paths, "toggled",
 							G_CALLBACK (on_toggle_hide_paths), ap);
-		g_signal_connect (GTK_OBJECT (checkb_hide_params), "toggled",
+		g_signal_connect (checkb_hide_params, "toggled",
 							G_CALLBACK (on_toggle_hide_params), ap);
-		g_signal_connect (GTK_OBJECT (checkb_process_tree), "toggled",
+		g_signal_connect (checkb_process_tree, "toggled",
 							G_CALLBACK (on_toggle_process_tree), ap);
 	}
 	
@@ -835,12 +836,12 @@ attach_process_destroy (AttachProcess * ap)
 static gboolean
 show_check_debug_dialog (DmaStart *this)
 {
-	AnjutaPreferences* prefs = anjuta_preferences_default ();
+	GSettings* settings = g_settings_new (PREF_SCHEMA);
 	gboolean no_check_debug;
 	gint res = GTK_RESPONSE_OK;
 
-	no_check_debug = anjuta_preferences_get_bool (prefs, 
-	                                              PREFS_NOT_CHECK_DEBUG);
+	no_check_debug = g_settings_get_boolean (settings, 
+	                                         PREFS_NOT_CHECK_DEBUG);
 	
 	if (!no_check_debug)
 	{
@@ -864,12 +865,14 @@ show_check_debug_dialog (DmaStart *this)
 	
 		if (gtk_toggle_button_get_active	(do_not_show))
 		{
-			anjuta_preferences_set_bool (prefs, PREFS_NOT_CHECK_DEBUG, TRUE);
+			g_settings_set_boolean (settings, PREFS_NOT_CHECK_DEBUG, TRUE);
 		}
 	
 		gtk_widget_destroy (dialog);
 	}
 
+	g_object_unref (settings);
+	
 	return res == GTK_RESPONSE_OK;
 }
 
