@@ -257,6 +257,43 @@ on_close_all_file_activate (GtkAction *action, gpointer user_data)
 	}
 }
 
+void 
+on_close_other_file_activate (GtkAction *action, gpointer user_data)
+{
+	GList *buffers;
+	AnjutaDocman *docman;
+	IAnjutaDocument *curr_doc;
+	DocmanPlugin *plugin;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
+	docman = ANJUTA_DOCMAN (plugin->docman);
+	
+	/* Close all 'saved' files */
+	buffers = anjuta_docman_get_all_doc_widgets (docman);
+	if (buffers)
+	{
+		GList *node;
+		node = buffers;
+
+		curr_doc = anjuta_docman_get_current_document (docman);
+		while (node)
+		{	
+			IAnjutaDocument *doc;
+			GList* next;
+			doc = IANJUTA_DOCUMENT (node->data);
+			next = g_list_next (node); /* grab it now, as we may change it. */
+			if (doc && doc != curr_doc)
+			{
+				if (!ianjuta_file_savable_is_dirty (IANJUTA_FILE_SAVABLE (doc), NULL))
+				{
+					anjuta_docman_remove_document (docman, doc);
+				}
+			}
+			node = next;
+		}
+		g_list_free (buffers);
+	}	
+}
+
 void
 on_reload_file_activate (GtkAction *action, gpointer user_data)
 {
@@ -696,13 +733,13 @@ on_goto_block_end1_activate (GtkAction *action, gpointer user_data)
 		ianjuta_editor_goto_end_block (IANJUTA_EDITOR_GOTO (doc), NULL);
 }
 
-#define VIEW_LINENUMBERS_MARGIN    "margin.linenumber.visible"
-#define VIEW_MARKER_MARGIN         "margin.marker.visible"
-#define VIEW_FOLD_MARGIN           "margin.fold.visible"
-#define VIEW_INDENTATION_GUIDES    "view.indentation.guides"
-#define VIEW_WHITE_SPACES          "view.whitespace"
-#define VIEW_EOL                   "view.eol"
-#define VIEW_LINE_WRAP             "view.line.wrap"
+#define VIEW_LINENUMBERS_MARGIN    "docman-linenumber-visible"
+#define VIEW_MARKER_MARGIN         "docman-marker-visible"
+#define VIEW_FOLD_MARGIN           "docman-fold-visible"
+#define VIEW_INDENTATION_GUIDES    "docman-indentation-guides"
+#define VIEW_WHITE_SPACES          "docman-whitespace"
+#define VIEW_EOL                   "docman-eol"
+#define VIEW_LINE_WRAP             "docman-line-wrap"
 
 void
 on_editor_linenos1_activate (GtkAction *action, gpointer user_data)
@@ -711,8 +748,8 @@ on_editor_linenos1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_LINENUMBERS_MARGIN, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_LINENUMBERS_MARGIN, state);
 }
 
 void
@@ -722,8 +759,8 @@ on_editor_markers1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_MARKER_MARGIN, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_MARKER_MARGIN, state);
 }
 
 void
@@ -733,8 +770,8 @@ on_editor_codefold1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_FOLD_MARGIN, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_FOLD_MARGIN, state);
 }
 
 void
@@ -744,8 +781,8 @@ on_editor_indentguides1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_INDENTATION_GUIDES, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_INDENTATION_GUIDES, state);
 }
 
 void
@@ -755,8 +792,8 @@ on_editor_whitespaces1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_WHITE_SPACES, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_WHITE_SPACES, state);
 }
 
 void
@@ -766,8 +803,8 @@ on_editor_eolchars1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_EOL, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_EOL, state);
 }
 
 void
@@ -777,8 +814,8 @@ on_editor_linewrap1_activate (GtkAction *action, gpointer user_data)
 	DocmanPlugin *plugin;
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	anjuta_preferences_set_bool (plugin->prefs,
-								VIEW_LINE_WRAP, state);
+	g_settings_set_boolean (plugin->settings,
+	                        VIEW_LINE_WRAP, state);
 }
 
 void
