@@ -53,12 +53,15 @@
 
 /* Preferences keys */
 
-#define PREF_INDENT_AUTOMATIC "language.cpp.indent.automatic"
-#define PREF_INDENT_STATEMENT_SIZE "language.cpp.indent.statement.size"
-#define PREF_INDENT_BRACE_SIZE "language.cpp.indent.brace.size"
-#define PREF_INDENT_PARANTHESE_LINEUP "language.cpp.indent.paranthese.lineup"
-#define PREF_INDENT_PARANTHESE_SIZE "language.cpp.indent.paranthese.size"
-#define PREF_BRACE_AUTOCOMPLETION "language.cpp.brace.autocompletion"
+#define PREF_SCHEMA "org.gnome.anjuta.cpp"
+#define PREF_INDENT_AUTOMATIC "cpp-indent-automatic"
+#define PREF_INDENT_MODELINE "cpp-indent-modeline"
+#define PREF_INDENT_STATEMENT_SIZE "cpp-indent-statement-size"
+#define PREF_INDENT_BRACE_SIZE "cpp-indent-brace-size"
+#define PREF_INDENT_PARANTHESE_LINEUP "cpp-indent-paranthese-lineup"
+#define PREF_INDENT_PARANTHESE_SIZE "cpp-indent-paranthese-size"
+#define PREF_BRACE_AUTOCOMPLETION "cpp-brace-autocompletion"
+#define PREF_COMMENT_LEADING_ASTERISK "cpp-multiline-leading-asterisk"
 
 #define TAB_SIZE (ianjuta_editor_get_tabsize (editor, NULL))
 
@@ -67,12 +70,12 @@
 #define INDENT_SIZE \
 	(plugin->param_statement_indentation >= 0? \
 		plugin->param_statement_indentation : \
-		anjuta_preferences_get_int (plugin->prefs, PREF_INDENT_STATEMENT_SIZE))
+		g_settings_get_int (plugin->settings, PREF_INDENT_STATEMENT_SIZE))
 
 #define BRACE_INDENT \
 	(plugin->param_brace_indentation >= 0? \
 		plugin->param_brace_indentation : \
-		anjuta_preferences_get_int (plugin->prefs, PREF_INDENT_BRACE_SIZE))
+		g_settings_get_int (plugin->settings, PREF_INDENT_BRACE_SIZE))
 
 #define CASE_INDENT (INDENT_SIZE)
 #define LABEL_INDENT (INDENT_SIZE)
@@ -583,7 +586,7 @@ initialize_indentation_params (CppJavaPlugin *plugin)
 	gboolean line_comment = FALSE;
 	gchar mini_buffer[MINI_BUFFER_SIZE] = {0};
 	
-	plugin->smart_indentation = anjuta_preferences_get_bool (plugin->prefs, PREF_INDENT_AUTOMATIC);
+	plugin->smart_indentation = g_settings_get_boolean (plugin->settings, PREF_INDENT_AUTOMATIC);
 	/* Disable editor intern auto-indent if smart indentation is enabled */
 	ianjuta_editor_set_auto_indent (IANJUTA_EDITOR(plugin->current_editor),
 								    !plugin->smart_indentation, NULL);
@@ -595,84 +598,88 @@ initialize_indentation_params (CppJavaPlugin *plugin)
 	plugin->param_case_indentation = -1;
 	plugin->param_label_indentation = -1;
 	plugin->param_use_spaces = -1;
-	
-	/* Find the first comment text in the buffer */
-	comment_text = g_string_new (NULL);
-	iter = ianjuta_editor_get_start_position (IANJUTA_EDITOR (plugin->current_editor),
-											  NULL);
-	do
+
+	if (g_settings_get_boolean (plugin->settings,
+	                            PREF_INDENT_MODELINE))
 	{
-		gboolean shift_buffer = TRUE;
-		gint i;
-		gchar ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
-												 0, NULL);
-		
-		for (i = 0; i < MINI_BUFFER_SIZE - 1; i++)
+		/* Find the first comment text in the buffer */
+		comment_text = g_string_new (NULL);
+		iter = ianjuta_editor_get_start_position (IANJUTA_EDITOR (plugin->current_editor),
+		                                          NULL);
+		do
 		{
-			if (mini_buffer[i] == '\0')
-			{
-				mini_buffer[i] = ch;
-				shift_buffer = FALSE;
-				break;
-			}
-		}
-		if (shift_buffer == TRUE)
-		{
-			/* Shift buffer and add */
+			gboolean shift_buffer = TRUE;
+			gint i;
+			gchar ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
+			                                         0, NULL);
+
 			for (i = 0; i < MINI_BUFFER_SIZE - 1; i++)
-				mini_buffer [i] = mini_buffer[i+1];
-			mini_buffer[i] = ch;
-		}
-		
-		if (!comment_begun && strncmp (mini_buffer, "/*", 2) == 0)
-		{
-			comment_begun = TRUE;
-			/* Reset buffer */
-			mini_buffer[0] = mini_buffer[1] = '\0';
-		}
-		else if (!comment_begun && strncmp (mini_buffer, "//", 2) == 0)
-		{
-			comment_begun = TRUE;
-			line_comment = TRUE;
-		}
-		else if (!comment_begun && mini_buffer[1] != '\0')
-		{
-			/* The buffer doesn't begin with a comment */
-			break;
-		}
-		else if (comment_begun)
-		{
-			if ((line_comment && ch == '\n') ||
-				(!line_comment && strncmp (mini_buffer, "*/", 2) == 0))
 			{
-				break;
+				if (mini_buffer[i] == '\0')
+				{
+					mini_buffer[i] = ch;
+					shift_buffer = FALSE;
+					break;
+				}
+			}
+			if (shift_buffer == TRUE)
+			{
+				/* Shift buffer and add */
+				for (i = 0; i < MINI_BUFFER_SIZE - 1; i++)
+					mini_buffer [i] = mini_buffer[i+1];
+				mini_buffer[i] = ch;
+			}
+
+			if (!comment_begun && strncmp (mini_buffer, "/*", 2) == 0)
+			{
+				comment_begun = TRUE;
+				/* Reset buffer */
+				mini_buffer[0] = mini_buffer[1] = '\0';
+			}
+			else if (!comment_begun && strncmp (mini_buffer, "//", 2) == 0)
+			                                    {
+													comment_begun = TRUE;
+													line_comment = TRUE;
+												}
+			                                    else if (!comment_begun && mini_buffer[1] != '\0')
+			                                    {
+													/* The buffer doesn't begin with a comment */
+													break;
+												}
+			                                    else if (comment_begun)
+			                                    {
+													if ((line_comment && ch == '\n') ||
+													    (!line_comment && strncmp (mini_buffer, "*/", 2) == 0))
+													{
+														break;
+													}
+												}
+
+			                                    if (comment_begun)
+			                                    g_string_append_c (comment_text, ch);
+
+		                                    }
+		while (ianjuta_iterable_next (iter, NULL));
+
+		/* DEBUG_PRINT ("Comment text: %s", comment_text->str);*/
+		if (comment_text->len > 0)
+		{
+
+			/* First comment found */
+			gboolean vim;
+			gchar *modeline = extract_mode_line (comment_text->str, &vim);
+			if (modeline)
+			{
+				if (!vim)
+					parse_mode_line_emacs (plugin, modeline);
+				else
+					parse_mode_line_vim (plugin, modeline);
+				g_free (modeline);
 			}
 		}
-		
-		if (comment_begun)
-			g_string_append_c (comment_text, ch);
-		
+		g_string_free (comment_text, TRUE);
+		g_object_unref (iter);
 	}
-	while (ianjuta_iterable_next (iter, NULL));
-	
-	/* DEBUG_PRINT ("Comment text: %s", comment_text->str);*/
-	if (comment_text->len > 0)
-	{
-		
-		/* First comment found */
-    gboolean vim;
-		gchar *modeline = extract_mode_line (comment_text->str, &vim);
-		if (modeline)
-		{
-      if (!vim)
-			  parse_mode_line_emacs (plugin, modeline);
-      else
-        parse_mode_line_vim (plugin, modeline);
-			g_free (modeline);
-		}
-	}
-	g_string_free (comment_text, TRUE);
-	g_object_unref (iter);
 }
 
 static gint
@@ -838,7 +845,12 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 	gboolean current_line_is_preprocessor = FALSE;
 	gboolean current_line_is_continuation = FALSE;
 	gboolean line_checked_for_comment = FALSE;
-	
+
+    /* Determine whether or not to add multi-line comment asterisks */
+	gchar* comment_continued = " * ";
+	IAnjutaIterable* line_begin = ianjuta_editor_get_line_begin_position (editor, line_num, NULL);
+	IAnjutaIterable* line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+
 	*incomplete_statement = -1;
 	*line_indent_spaces = 0;
 	
@@ -961,10 +973,20 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 						if (!comment_end)
 						{
 							extra_indent++;
+
+							/* If a multiline comment is continuing, check the next line and insert " * " 
+							 * only if it does not already exist there. The purpose of this fix is to avoid
+							 * extra " * " on auto-indent. */
+
+							if (g_settings_get_boolean (plugin->settings, PREF_COMMENT_LEADING_ASTERISK) &&
+									ianjuta_iterable_compare (line_end, line_begin, NULL) == 0)
+								ianjuta_editor_insert (editor, line_begin, comment_continued, -1, NULL);
+
 							/* In the middle of a comment we can't know
 						     * if the statement is incomplete
 							 */
 							*incomplete_statement = -1;
+							
 							/* ":" have to be ignored inside comments */
 							if (*colon_indent)
 							{
@@ -1073,8 +1095,8 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 		else if (point_ch == '(' || point_ch == '[')
 		{
 			line_indent = 0;
-			if (anjuta_preferences_get_bool (plugin->prefs,
-			                                 PREF_INDENT_PARANTHESE_LINEUP))
+			if (g_settings_get_boolean (plugin->settings,
+			                            PREF_INDENT_PARANTHESE_LINEUP))
 			{
 				while (ianjuta_iterable_previous (iter, NULL))
 				{
@@ -1100,8 +1122,8 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 				line_indent = get_line_indentation (editor, line_for_indent);
 				line_indent += extra_indent;
 
-				(*line_indent_spaces) += anjuta_preferences_get_int (plugin->prefs,
-				                                                     PREF_INDENT_PARANTHESE_SIZE);
+				(*line_indent_spaces) += g_settings_get_boolean (plugin->settings,
+				                                                 PREF_INDENT_PARANTHESE_SIZE);
 			}
 			
 			/* Although statement is incomplete at this point, we don't
@@ -1406,22 +1428,6 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 	return line_indent;
 }
 
-static void on_editor_char_inserted_cpp (IAnjutaEditor *editor,
-                                         IAnjutaIterable *insert_pos,
-                                         gchar ch,
-                                         CppJavaPlugin *plugin);
-
-static void
-insert_editor_blocked (IAnjutaEditor* editor,
-                       IAnjutaIterable* iter,
-                       gchar* text,
-                       CppJavaPlugin* plugin)
-{
-	g_signal_handlers_block_by_func (editor, on_editor_char_inserted_cpp, plugin);
-	ianjuta_editor_insert (editor, iter, text, -1, NULL);
-	g_signal_handlers_unblock_by_func (editor, on_editor_char_inserted_cpp, plugin);
-}
-
 static void
 on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 							 IAnjutaIterable *insert_pos,
@@ -1500,7 +1506,7 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 		}
 	}
 	
-	if (anjuta_preferences_get_bool (plugin->prefs, PREF_BRACE_AUTOCOMPLETION))
+	if (g_settings_get_boolean (plugin->settings, PREF_BRACE_AUTOCOMPLETION))
 	{
 		if (ch == '[' || ch == '(')
 		{
@@ -1519,12 +1525,12 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 				switch (ch)
 				{
 					case '[': 
-							  insert_editor_blocked (editor, iter,
-													 "]", plugin);
+							  ianjuta_editor_insert (editor, iter,
+													 "]", 1, NULL);
 							  break;
 					case '(': 
-							  insert_editor_blocked (editor, iter,
-													 ")", plugin);
+							  ianjuta_editor_insert (editor, iter,
+													 ")", 1, NULL);
 							  break;
 					default: 
 						       break;
@@ -1564,7 +1570,7 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 					else c = g_strdup ("'");
 					
 					ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (editor), NULL);
-					insert_editor_blocked (editor, iter, c, plugin);
+					ianjuta_editor_insert (editor, iter, c, 1, NULL);
 					ianjuta_editor_goto_position (editor, iter, NULL);
 					ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (editor), NULL);	
 					
@@ -1644,7 +1650,7 @@ install_support (CppJavaPlugin *lang_plugin)
 					anjuta_shell_get_interface (ANJUTA_PLUGIN (lang_plugin)->shell,
 												IAnjutaSymbolManager,
 												NULL),
-					lang_plugin->prefs);
+					lang_plugin->settings);
 		lang_plugin->assist = assist;
 	}	
 		
@@ -1939,7 +1945,6 @@ cpp_java_plugin_activate_plugin (AnjutaPlugin *plugin)
 		register_stock_icons (plugin);
 	}
 
-	lang_plugin->prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	lang_plugin->action_group = 
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupCppJavaAssist",
@@ -1993,7 +1998,11 @@ cpp_java_plugin_finalize (GObject *obj)
 static void
 cpp_java_plugin_dispose (GObject *obj)
 {
+	CppJavaPlugin* plugin = ANJUTA_PLUGIN_CPP_JAVA (obj);
 	/* Disposition codes */
+
+	g_object_unref (plugin->settings);
+	
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
@@ -2007,6 +2016,7 @@ cpp_java_plugin_instance_init (GObject *obj)
 	plugin->editor_watch_id = 0;
 	plugin->uiid = 0;
 	plugin->assist = NULL;
+	plugin->settings = g_settings_new (PREF_SCHEMA);
 }
 
 static void
@@ -2022,9 +2032,9 @@ cpp_java_plugin_class_init (GObjectClass *klass)
 	klass->dispose = cpp_java_plugin_dispose;
 }
 
-#define PREF_WIDGET_SPACE "preferences_toggle:bool:1:1:language.cpp.code.completion.space.after.func"
-#define PREF_WIDGET_BRACE "preferences_toggle:bool:1:1:language.cpp.code.completion.brace.after.func"
-#define PREF_WIDGET_AUTO "preferences_toggle:bool:1:1:language.cpp.code.completion.enable"
+#define PREF_WIDGET_SPACE "preferences_toggle:bool:1:1:cpp-completion-space-after-func"
+#define PREF_WIDGET_BRACE "preferences_toggle:bool:1:1:cpp-completion-brace-after-func"
+#define PREF_WIDGET_AUTO "preferences_toggle:bool:1:1:cpp-completion-enable"
 
 static void
 on_autocompletion_toggled (GtkToggleButton* button,
@@ -2055,8 +2065,9 @@ ipreferences_merge (IAnjutaPreferences* ipref, AnjutaPreferences* prefs,
 		g_error_free (error);
 	}
 	anjuta_preferences_add_from_builder (prefs,
-								 plugin->bxml, "preferences", _("C/C++/Java/Vala"),
-								 ICON_FILE);
+	                                     plugin->bxml, plugin->settings,
+	                                     "preferences", _("C/C++/Java/Vala"),
+	                                     ICON_FILE);
 	toggle = GTK_WIDGET (gtk_builder_get_object (plugin->bxml, PREF_WIDGET_AUTO));
 	g_signal_connect (toggle, "toggled", G_CALLBACK (on_autocompletion_toggled),
 	                  plugin->bxml);
