@@ -22,7 +22,7 @@
 #include <libanjuta/anjuta-preferences.h>
 #include "message-view.h"
 
-#define MESSAGES_TABS_POS  "messages.tab.position"
+#define MESSAGES_TABS_POS "messages-tab-position"
 
 #define ANJUTA_TYPE_MSGMAN        (anjuta_msgman_get_type ())
 #define ANJUTA_MSGMAN(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_MSGMAN, AnjutaMsgman))
@@ -79,10 +79,10 @@ gboolean anjuta_msgman_serialize (AnjutaMsgman *msgman,
 gboolean anjuta_msgman_deserialize (AnjutaMsgman *msgman,
 									AnjutaSerializer *serializer);
 
-GtkWidget* anjuta_msgman_get_hbox (AnjutaMsgman* msgman);
+GtkWidget* anjuta_msgman_get_tabber (AnjutaMsgman* msgman);
 
 void
-on_notify_message_pref (AnjutaPreferences* prefs, const gchar* key,
-                        const gchar* value, gpointer user_data);
+on_notify_message_pref (GSettings* settings, const gchar* key,
+                        gpointer user_data);
 
 #endif /* _ANJUTA_MSGMAN_H */
