@@ -43,7 +43,9 @@ struct SourceviewPrivate {
 	gboolean read_only;
 	
 	/* Preferences */
-	AnjutaPreferences* prefs;
+	GSettings* settings;
+	GSettings* docman_settings;
+	GSettings* msgman_settings;
 	GList* notify_ids;
 	
 	/* Popup menu */
